@@ -11,10 +11,10 @@ from aiopg import create_pool
 
 
 class PostgresqlPool(BaseConnectionPool):
-
     """
     Postgresql 数据库链接创建类
     """
+
     async def create_pool(self):
         print("Postgresql create_pool")
         """
@@ -32,6 +32,6 @@ class PostgresqlPool(BaseConnectionPool):
             raise NotImplementedError
 
     def sync_create_pool(self):
-        pool = PooledDB(psycopg2, 5, host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
+        pool = PooledDB(psycopg2, host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
                         password=self.conn_info.password, database=self.conn_info.db_name)
         return pool
