@@ -115,6 +115,10 @@ class StatusCode:
     TASK_NOT_EXIST = ("B0105", "任务不存在")
     COMPANY_CERTIFICATION_FAIL = ("B0106", "企业认证失败")
     IDENTITY_CERTIFICATION_FAIL = ("B0107", "身份证认证失败")
+    COMPANY_CERTIFICATION_OTHER = ("B0108", "企业已经被认证")
+    IDENTITY_CERTIFICATION_OTHER = ("B0109", "身份证已认证")
+    COMPANY_CERTIFICATION_PENDING = ("B0110", "企业正在认证")
+    IDENTITY_CERTIFICATION_PENDING = ("B0111", "身份证正在认证")
     # B02开头的状态码
     STRIKE_RECOVERY = ("B0200", "系统容灾系统被触发")
     # B03开头的状态码
